# ⭐ 0.0.3 | 2024-03-25
- Organized timeseries building functions into the ts submodule.
- Rename `mrms.timeseries` to `mrms.ts`.
- Add `mrms.plot` submodule.
- Build timeseries using polygons.


## Previous notes:

**0.0.2 | 2024-03-20**
- Add `mrms.timeseries` tools. For larger datasets, these run faster than using `xr.open_mfdataset`.
- Add docstrings to functions.

**0.0.1 | 2024-03-19**
- Initial release.
- Add `mrms.download_data` helper.